==> j2sdk-1_4_2_04-i586-3.tgz: com/sun/java/swing/plaf/gtk/resources/gtk_ja.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk_ja extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "*" },
        { "FileChooser.cancelButtonText", "\u53D6\u6D88\u3057" },
        { "FileChooser.cancelButtonToolTipText", "\u30D5\u30A1\u30A4\u30EB\u30C1\u30E5\u30FC\u30B6\u30C0\u30A4\u30A2\u30ED\u30B0\u3092\u5F37\u5236\u7D42\u4E86" },
        { "FileChooser.deleteFileButtonText", "\u30D5\u30A1\u30A4\u30EB\u3092\u524A\u9664" },
        { "FileChooser.filesLabelText", "\u30D5\u30A1\u30A4\u30EB" },
        { "FileChooser.foldersLabelText", "\u30D5\u30A9\u30EB\u30C0" },
        { "FileChooser.newFolderButtonText", "\u65B0\u898F\u30D5\u30A9\u30EB\u30C0" },
        { "FileChooser.openButtonText", "\u4E86\u89E3" },
        { "FileChooser.openButtonToolTipText", "\u9078\u629E\u3057\u305F\u30D5\u30A1\u30A4\u30EB\u3092\u958B\u304F" },
        { "FileChooser.openDialogTitleText", "\u958B\u304F" },
        { "FileChooser.pathLabelText", "\u9078\u629E:" },
        { "FileChooser.renameFileButtonText", "\u30D5\u30A1\u30A4\u30EB\u540D\u3092\u5909\u66F4" },
        { "FileChooser.saveButtonText", "\u4FDD\u5B58" },
        { "FileChooser.saveButtonToolTipText", "\u9078\u629E\u3057\u305F\u30D5\u30A1\u30A4\u30EB\u3092\u4FDD\u5B58" },
        { "FileChooser.saveDialogTitleText", "\u4FDD\u5B58" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "\u9752(B):" },
        { "GTKColorChooserPanel.colorNameMnemonic", "78" },
        { "GTKColorChooserPanel.colorNameText", "\u8272\u540D(N):" },
        { "GTKColorChooserPanel.greenMnemonic", "71" },
        { "GTKColorChooserPanel.greenText", "\u7DD1(G):" },
        { "GTKColorChooserPanel.hueMnemonic", "72" },
        { "GTKColorChooserPanel.hueText", "\u8272\u5408\u3044(H):" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "GTK \u30AB\u30E9\u30FC\u30C1\u30E5\u30FC\u30B6" },
        { "GTKColorChooserPanel.redMnemonic", "82" },
        { "GTKColorChooserPanel.redText", "\u8D64(R):" },
        { "GTKColorChooserPanel.saturationMnemonic", "83" },
        { "GTKColorChooserPanel.saturationText", "\u5F69\u5EA6(S):" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "\u5024(V):" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}

==> j2sdk-1_5_0_01-i586-1.tgz: com/sun/java/swing/plaf/gtk/resources/gtk_ja.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk_ja extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "\u3059\u3079\u3066\u306E\u30D5\u30A1\u30A4\u30EB" },
        { "FileChooser.cancelButtonText", "\u53D6\u6D88\u3057" },
        { "FileChooser.cancelButtonToolTipText", "\u30D5\u30A1\u30A4\u30EB\u30C1\u30E5\u30FC\u30B6\u30C0\u30A4\u30A2\u30ED\u30B0\u3092\u5F37\u5236\u7D42\u4E86" },
        { "FileChooser.deleteFileButtonText", "\u30D5\u30A1\u30A4\u30EB\u3092\u524A\u9664" },
        { "FileChooser.filesLabelText", "\u30D5\u30A1\u30A4\u30EB" },
        { "FileChooser.filterLabelText", "\u30D5\u30A3\u30EB\u30BF:" },
        { "FileChooser.foldersLabelText", "\u30D5\u30A9\u30EB\u30C0" },
        { "FileChooser.newFolderButtonText", "\u65B0\u898F\u30D5\u30A9\u30EB\u30C0" },
        { "FileChooser.newFolderDialogText", "\u30D5\u30A9\u30EB\u30C0\u540D:" },
        { "FileChooser.openButtonText", "\u4E86\u89E3" },
        { "FileChooser.openButtonToolTipText", "\u9078\u629E\u3057\u305F\u30D5\u30A1\u30A4\u30EB\u3092\u958B\u304F" },
        { "FileChooser.openDialogTitleText", "\u958B\u304F" },
        { "FileChooser.pathLabelText", "\u9078\u629E:" },
        { "FileChooser.renameFileButtonText", "\u30D5\u30A1\u30A4\u30EB\u540D\u3092\u5909\u66F4" },
        { "FileChooser.renameFileDialogText", "\u30D5\u30A1\u30A4\u30EB \"{0}\" \u306E\u540D\u524D\u3092\u5909\u66F4:" },
        { "FileChooser.renameFileErrorText", "\u30D5\u30A1\u30A4\u30EB \"{0}\" \u3092 \"{1}\" \u3078\u5909\u66F4\u6642\u306B\u30A8\u30E9\u30FC" },
        { "FileChooser.renameFileErrorTitle", "\u30A8\u30E9\u30FC " },
        { "FileChooser.saveButtonText", "\u4FDD\u5B58" },
        { "FileChooser.saveButtonToolTipText", "\u9078\u629E\u3057\u305F\u30D5\u30A1\u30A4\u30EB\u3092\u4FDD\u5B58" },
        { "FileChooser.saveDialogTitleText", "\u4FDD\u5B58" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "\u9752(B):" },
        { "GTKColorChooserPanel.colorNameMnemonic", "78" },
        { "GTKColorChooserPanel.colorNameText", "\u8272\u540D(N):" },
        { "GTKColorChooserPanel.greenMnemonic", "71" },
        { "GTKColorChooserPanel.greenText", "\u7DD1(G):" },
        { "GTKColorChooserPanel.hueMnemonic", "72" },
        { "GTKColorChooserPanel.hueText", "\u8272\u5408\u3044(H):" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "GTK \u30AB\u30E9\u30FC\u30C1\u30E5\u30FC\u30B6" },
        { "GTKColorChooserPanel.redMnemonic", "69" },
        { "GTKColorChooserPanel.redText", "\u8D64(E):" },
        { "GTKColorChooserPanel.saturationMnemonic", "83" },
        { "GTKColorChooserPanel.saturationText", "\u5F69\u5EA6(S):" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "\u5024(V):" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}
